import {
  Account,
  activeAccountContext,
  createAnonymousJazzContext
} from "./chunk-ICWP2U63.js";

// src/testing.ts
import { cojsonInternals } from "cojson";
import { PureJSCrypto } from "cojson/crypto";
var TestJSCrypto = class extends PureJSCrypto {
  static async create() {
    if ("navigator" in globalThis && navigator.userAgent.includes("jsdom")) {
      const crypto = new PureJSCrypto();
      crypto.seal = (options) => `sealed_U${cojsonInternals.stableStringify(options.message)}`;
      crypto.unseal = (sealed) => JSON.parse(sealed.substring("sealed_U".length));
      crypto.encrypt = (message) => `encrypted_U${cojsonInternals.stableStringify(message)}`;
      crypto.decryptRaw = (encrypted) => encrypted.substring("encrypted_U".length);
      return crypto;
    }
    return new PureJSCrypto();
  }
};
async function createJazzTestAccount(options) {
  const AccountSchema = options?.AccountSchema ?? Account;
  const account = await AccountSchema.create({
    creationProps: {
      name: "Test Account"
    },
    crypto: await TestJSCrypto.create()
  });
  if (options?.isCurrentActiveAccount) {
    activeAccountContext.set(account);
  }
  return account;
}
function setActiveAccount(account) {
  activeAccountContext.set(account);
}
async function createJazzTestGuest() {
  const ctx = await createAnonymousJazzContext({
    crypto: await PureJSCrypto.create(),
    peersToLoadFrom: []
  });
  return {
    guest: ctx.agent
  };
}
function getJazzContextShape(account) {
  if ("guest" in account) {
    return {
      guest: account.guest,
      AccountSchema: Account,
      logOut: () => account.guest.node.gracefulShutdown(),
      done: () => account.guest.node.gracefulShutdown()
    };
  }
  return {
    me: account,
    AccountSchema: account.constructor,
    logOut: () => account._raw.core.node.gracefulShutdown(),
    done: () => account._raw.core.node.gracefulShutdown()
  };
}
function linkAccounts(a, b, aRole = "server", bRole = "server") {
  const [aPeer, bPeer] = cojsonInternals.connectedPeers(b.id, a.id, {
    peer1role: aRole,
    peer2role: bRole
  });
  a._raw.core.node.syncManager.addPeer(aPeer);
  b._raw.core.node.syncManager.addPeer(bPeer);
}
export {
  createJazzTestAccount,
  createJazzTestGuest,
  getJazzContextShape,
  linkAccounts,
  setActiveAccount
};
//# sourceMappingURL=testing.js.map